#line 1 "/build/adios2/src/build/thirdparty/ffs/ffs/lex.yy.c"

#line 3 "/build/adios2/src/build/thirdparty/ffs/ffs/lex.yy.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 107
#define YY_END_OF_BUFFER 108
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[284] =
    {   0,
        0,    0,    0,    0,   90,   90,  108,  107,  105,  106,
       72,   76,   12,   38,  107,    2,    3,    9,   13,    8,
       14,    7,   11,   96,   96,   73,   42,   17,   24,   19,
       74,   10,   75,   75,    4,    5,   39,   75,   75,   75,
       75,   75,   75,   75,   75,   75,   75,   75,   75,   75,
       75,   70,   37,   71,   15,   88,   78,   77,  107,   90,
       92,   91,   23,   27,   36,   32,    0,    0,   25,   40,
       28,   41,   29,    1,    0,  103,   89,   94,   26,  104,
       96,    0,   96,   96,    0,    0,   96,    0,   20,   16,
       22,   18,   21,   75,    0,   33,   75,   75,   75,   47,

       75,   75,   75,   75,   75,   75,   43,   75,   75,   75,
       75,   75,   75,   75,   75,   75,   75,   34,   35,   88,
       87,   80,   81,   85,   86,   82,   84,   83,   87,   90,
       91,   91,   93,   95,    0,    0,    6,    0,  103,   94,
      103,    0,  104,    0,  102,   96,   96,   96,   96,    0,
        0,   98,   97,   30,   31,   75,   75,   75,   75,   75,
       75,   75,   75,   45,   75,   51,   75,   75,   75,   75,
       75,   75,   75,   75,   75,   75,   75,   75,   80,   81,
       79,    0,    0,    0,  103,    0,  103,    0,  104,  102,
       96,    0,    0,    0,   98,   98,   98,   97,   97,   97,

       75,   53,   75,   75,   75,   44,   67,   75,   75,   63,
       52,   75,   75,   75,   75,   75,   75,   75,   75,   75,
       75,   57,   75,   80,    0,    0,    0,  103,    0,    0,
        0,   99,   98,   98,   98,   98,   97,   97,   97,   97,
       62,   64,   75,   75,   75,   55,   75,   50,   75,   75,
       75,   75,   75,   75,   68,   75,   46,    0,  100,    0,
      101,   99,   98,   97,   75,   56,   59,   69,   49,   65,
       58,   54,   66,   75,   75,  100,  101,   75,   60,   75,
       61,   48,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    4,    5,    1,    1,    6,    7,    8,    9,
       10,   11,   12,   13,   14,   15,   16,   17,   18,   19,
       19,   19,   19,   19,   19,   20,   20,   21,   22,   23,
       24,   25,   26,   27,   28,   28,   28,   28,   29,   30,
       31,   31,   31,   31,   31,   32,   31,   31,   31,   33,
       31,   31,   31,   31,   34,   31,   31,   35,   31,   31,
       36,   37,   38,   39,   31,    1,   40,   41,   42,   43,

       44,   45,   46,   47,   48,   31,   49,   50,   51,   52,
       53,   54,   31,   55,   56,   57,   58,   59,   60,   61,
       62,   63,   64,   65,   66,   67,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[68] =
    {   0,
        1,    1,    2,    1,    3,    1,    1,    4,    1,    1,
        5,    1,    1,    1,    6,    1,    7,    7,    7,    8,
        1,    1,    1,    1,    1,    9,    1,    8,    8,    8,
       10,   10,   10,   10,   10,    1,    3,    1,    1,    7,
        7,    8,    8,    8,    7,   10,   10,   10,   10,   10,
       10,   11,   10,   10,   11,   10,   11,   10,   11,   10,
       11,   10,   10,    1,    1,    1,    1
    } ;

static const flex_int16_t yy_base[299] =
    {   0,
        0,    0,   65,   66,   69,   70,  614,  615,  615,  615,
      589,  615,  588,   67,  574,  615,  615,  586,   63,  615,
       64,   75,   85,   95,   44,  615,  615,   53,  585,   58,
      615,  615,    0,  600,  615,  615,  583,  551,   51,  552,
       47,   66,  551,   55,  550,  558,   74,  539,   76,  547,
      552,  615,   82,  615,  615,    0,  615,  615,  123,    0,
      615,  107,  615,  615,  615,  615,  109,  115,  615,  615,
      615,  615,  615,  615,  583,  141,  615,    0,  615,  170,
        0,  189,  116,   88,  582,  108,  147,  560,  548,  615,
      615,  615,  546,    0,  531,  615,  523,  515,  495,  486,

      467,  464,  461,  455,  451,  424,    0,  423,  427,  421,
      423,   89,  111,  421,  101,  426,  425,  615,  615,    0,
      615,  175,  193,  615,  615,  615,  615,  615,    0,    0,
      151,  161,  615,  615,  208,    0,  615,  216,  615,    0,
      220,  239,  615,  204,  243,  121,  615,  440,  421,    0,
      150,  237,  251,  615,  615,  430,  414,  161,  427,  423,
      414,  419,  420,    0,  406,    0,  411,  398,  400,  402,
      403,  388,   96,  395,  384,  370,  373,  364,  224,  259,
        0,  273,  303,  279,  307,  341,  615,  295,  345,  615,
      615,  165,  213,  354,  248,  197,  284,  270,  236,  320,

      364,    0,  355,  359,  352,    0,    0,  346,  343,    0,
        0,  334,  331,  343,  323,  321,  315,  314,  308,  298,
      303,    0,  294,  362,  266,    0,  366,  374,  391,  403,
      379,  408,  214,  615,  304,  285,  283,  615,  298,  279,
        0,    0,  267,  272,  256,    0,  255,    0,  257,  249,
      247,  186,  174,  152,    0,  130,    0,  412,  416,  424,
      432,  615,  615,  615,  111,    0,    0,    0,    0,    0,
        0,    0,    0,  118,   93,  615,  615,   67,    0,   43,
        0,    0,  615,  482,  493,  504,  509,  520,  531,  542,
      553,  562,  573,  579,  582,  584,  586,  588

    } ;

static const flex_int16_t yy_def[299] =
    {   0,
      283,    1,  284,  284,  285,  285,  283,  283,  283,  283,
      283,  283,  283,  283,  286,  283,  283,  283,  283,  283,
      283,  283,  283,  283,   24,  283,  283,  283,  283,  283,
      283,  283,  287,  287,  283,  283,  283,  287,  287,  287,
      287,  287,  287,  287,  287,  287,  287,  287,  287,  287,
      287,  283,  283,  283,  283,  288,  283,  283,  289,  290,
      283,  291,  283,  283,  283,  283,  286,  292,  283,  283,
      283,  283,  283,  283,  283,  283,  283,  293,  283,  283,
       25,  283,  283,  283,  294,  283,  283,  295,  283,  283,
      283,  283,  283,  287,  286,  283,  287,  287,  287,  287,

      287,  287,  287,  287,  287,  287,  287,  287,  287,  287,
      287,  287,  287,  287,  287,  287,  287,  283,  283,  288,
      283,  283,  283,  283,  283,  283,  283,  283,  296,  290,
      291,  291,  283,  283,  286,  297,  283,  283,  283,  293,
      283,  283,  283,  283,  283,  283,  283,  283,  283,  298,
      294,  283,  295,  283,  283,  287,  287,  287,  287,  287,
      287,  287,  287,  287,  287,  287,  287,  287,  287,  287,
      287,  287,  287,  287,  287,  287,  287,  287,  283,  283,
      296,  286,  286,  283,  283,  283,  283,  283,  283,  283,
      283,  298,  298,  283,  283,  283,  283,  283,  283,  283,

      287,  287,  287,  287,  287,  287,  287,  287,  287,  287,
      287,  287,  287,  287,  287,  287,  287,  287,  287,  287,
      287,  287,  287,  283,  286,  183,  283,  283,  283,  283,
      283,  283,  283,  283,  283,  283,  283,  283,  283,  283,
      287,  287,  287,  287,  287,  287,  287,  287,  287,  287,
      287,  287,  287,  287,  287,  287,  287,  283,  283,  283,
      283,  283,  283,  283,  287,  287,  287,  287,  287,  287,
      287,  287,  287,  287,  287,  283,  283,  287,  287,  287,
      287,  287,    0,  283,  283,  283,  283,  283,  283,  283,
      283,  283,  283,  283,  283,  283,  283,  283

    } ;

static const flex_int16_t yy_nxt[683] =
    {   0,
        8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
       18,   19,   20,   21,   22,   23,   24,   25,   25,   25,
       26,   27,   28,   29,   30,   31,   32,   33,   33,   33,
       33,   34,   33,   34,   33,   35,    8,   36,   37,   33,
       38,   39,   40,   41,   42,   43,   33,   44,   33,   45,
       33,   33,   33,   33,   46,   47,   48,   49,   50,   51,
       33,   33,   33,   52,   53,   54,   55,   57,   57,   58,
       58,   61,   61,   65,   70,   89,   90,   72,  283,   62,
       62,   92,   93,   95,  283,  282,   71,   73,   74,   75,
       66,   76,   76,   76,   76,   77,  101,   98,  102,  107,

       78,   59,   59,   99,  283,  118,  108,  103,   79,   80,
      281,   81,   81,   81,   81,  104,  134,  132,  105,  148,
      111,  112,  133,   82,  152,  152,   83,  115,   84,   85,
      113,  135,  135,  135,  170,   86,  280,  149,   82,  122,
      122,  122,  123,  217,   87,   68,  119,  146,  175,  147,
      172,  171,   84,  218,  147,   88,  176,   76,   76,   76,
       76,  283,  279,  124,  193,  173,  283,  125,  278,  138,
      139,  132,  139,  147,  126,  136,  133,  127,  147,  128,
      147,  275,  194,  129,  138,  139,  141,  141,  141,  141,
      139,  179,  179,  179,  180,  274,  146,  229,  142,  143,

      144,  143,  144,  194,  147,  145,  145,  145,  145,  180,
      180,  180,  180,  142,  143,  134,  203,  204,  229,  143,
      145,  145,  145,  145,  182,  182,  182,  184,  235,  184,
      273,  272,  185,  185,  185,  185,  141,  141,  141,  141,
      224,  224,  224,  180,   68,  230,  236,  234,  186,  187,
      188,  187,  188,  152,  152,  189,  189,  189,  189,  145,
      145,  145,  145,  186,  187,  193,  230,  239,  195,  187,
      196,  234,  190,  134,  190,  180,  180,  180,  180,  233,
      134,  234,  198,  194,  199,  240,  197,  190,  271,  225,
      225,  225,  190,  270,  196,  185,  185,  185,  185,  269,

      200,  237,   68,  238,  194,  234,  268,  267,  199,   68,
      134,  189,  189,  189,  189,  266,  238,  234,  265,  226,
      226,  226,  226,  185,  185,  185,  185,  238,  264,  264,
      226,  226,  226,  233,  263,  263,  139,  257,  139,   68,
      238,  234,  226,  226,  226,  226,  226,  226,  256,  255,
      254,  139,  227,  238,  227,  253,  139,  228,  228,  228,
      228,  189,  189,  189,  189,  231,  252,  231,  251,  237,
      232,  232,  232,  232,  143,  250,  143,  238,  180,  180,
      180,  180,  228,  228,  228,  228,  249,  248,  247,  143,
      228,  228,  228,  228,  143,  232,  232,  232,  232,  246,

      245,  244,  258,  187,  258,  187,  243,  259,  259,  259,
      259,  242,  241,  223,  260,  222,  260,  221,  187,  261,
      261,  261,  261,  187,  232,  232,  232,  232,  259,  259,
      259,  259,  259,  259,  259,  259,  220,  262,  219,  262,
      261,  261,  261,  261,  216,  276,  215,  276,  261,  261,
      261,  261,  262,  214,  213,  212,  211,  262,  210,  209,
      276,  277,  208,  277,  207,  276,  206,  205,  202,  201,
      191,  191,  178,  177,  174,  169,  277,  168,  167,  166,
      165,  277,   56,   56,   56,   56,   56,   56,   56,   56,
       56,   56,   56,   60,   60,   60,   60,   60,   60,   60,

       60,   60,   60,   60,   67,  164,   67,  163,   67,   67,
       67,   67,   67,   67,   67,   94,   94,  162,   94,   94,
      120,  161,  160,  120,  120,  120,  120,  120,  120,  120,
      120,  121,  121,  121,  121,  121,  121,  121,  121,  121,
      121,  121,  130,  159,  130,  130,  158,  130,  130,  130,
      130,  130,  130,  131,  157,  131,  131,  131,  131,  131,
      131,  131,  131,  131,   67,   67,  156,   68,   67,  155,
       67,  154,   67,  140,  150,  140,  140,  140,  140,  140,
      140,  140,  140,  140,  151,  151,  151,  153,  153,  153,
      181,  181,  183,  183,  192,  192,  150,  137,  117,  116,

      114,  110,  109,  106,  100,   97,   96,   95,   91,   69,
       68,   64,   63,  283,    7,  283,  283,  283,  283,  283,
      283,  283,  283,  283,  283,  283,  283,  283,  283,  283,
      283,  283,  283,  283,  283,  283,  283,  283,  283,  283,
      283,  283,  283,  283,  283,  283,  283,  283,  283,  283,
      283,  283,  283,  283,  283,  283,  283,  283,  283,  283,
      283,  283,  283,  283,  283,  283,  283,  283,  283,  283,
      283,  283,  283,  283,  283,  283,  283,  283,  283,  283,
      283,  283
    } ;

static const flex_int16_t yy_chk[683] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    3,    4,    3,
        4,    5,    6,   14,   19,   28,   28,   21,   25,    5,
        6,   30,   30,   49,   25,  280,   19,   21,   21,   22,
       14,   22,   22,   22,   22,   23,   41,   39,   41,   44,

       23,    3,    4,   39,   25,   53,   44,   41,   23,   24,
      278,   24,   24,   24,   24,   42,   67,   62,   42,   84,
       47,   47,   62,   24,   86,   86,   24,   49,   24,   24,
       47,   68,   68,   68,  112,   24,  275,   84,   24,   59,
       59,   59,   59,  173,   24,   67,   53,   83,  115,   83,
      113,  112,   24,  173,  146,   24,  115,   76,   76,   76,
       76,  131,  274,   59,  151,  113,  131,   59,  265,   76,
       76,  132,   76,   83,   59,   68,  132,   59,  146,   59,
       87,  256,  151,   59,   76,   76,   80,   80,   80,   80,
       76,  122,  122,  122,  122,  254,   87,  192,   80,   80,

       82,   80,   82,  151,   87,   82,   82,   82,   82,  123,
      123,  123,  123,   80,   80,  135,  158,  158,  192,   80,
      144,  144,  144,  144,  135,  135,  135,  138,  196,  138,
      253,  252,  138,  138,  138,  138,  141,  141,  141,  141,
      179,  179,  179,  179,  135,  193,  196,  233,  141,  141,
      142,  141,  142,  152,  152,  142,  142,  142,  142,  145,
      145,  145,  145,  141,  141,  153,  193,  199,  152,  141,
      152,  233,  145,  225,  145,  180,  180,  180,  180,  195,
      182,  195,  153,  153,  153,  199,  152,  145,  251,  182,
      182,  182,  145,  250,  152,  184,  184,  184,  184,  249,

      153,  198,  225,  198,  153,  195,  247,  245,  153,  182,
      183,  188,  188,  188,  188,  244,  237,  197,  243,  183,
      183,  183,  183,  185,  185,  185,  185,  198,  240,  239,
      183,  183,  183,  197,  236,  235,  185,  223,  185,  183,
      237,  197,  183,  183,  183,  183,  183,  183,  221,  220,
      219,  185,  186,  200,  186,  218,  185,  186,  186,  186,
      186,  189,  189,  189,  189,  194,  217,  194,  216,  200,
      194,  194,  194,  194,  189,  215,  189,  200,  224,  224,
      224,  224,  227,  227,  227,  227,  214,  213,  212,  189,
      228,  228,  228,  228,  189,  231,  231,  231,  231,  209,

      208,  205,  229,  228,  229,  228,  204,  229,  229,  229,
      229,  203,  201,  178,  230,  177,  230,  176,  228,  230,
      230,  230,  230,  228,  232,  232,  232,  232,  258,  258,
      258,  258,  259,  259,  259,  259,  175,  232,  174,  232,
      260,  260,  260,  260,  172,  259,  171,  259,  261,  261,
      261,  261,  232,  170,  169,  168,  167,  232,  165,  163,
      259,  261,  162,  261,  161,  259,  160,  159,  157,  156,
      149,  148,  117,  116,  114,  111,  261,  110,  109,  108,
      106,  261,  284,  284,  284,  284,  284,  284,  284,  284,
      284,  284,  284,  285,  285,  285,  285,  285,  285,  285,

      285,  285,  285,  285,  286,  105,  286,  104,  286,  286,
      286,  286,  286,  286,  286,  287,  287,  103,  287,  287,
      288,  102,  101,  288,  288,  288,  288,  288,  288,  288,
      288,  289,  289,  289,  289,  289,  289,  289,  289,  289,
      289,  289,  290,  100,  290,  290,   99,  290,  290,  290,
      290,  290,  290,  291,   98,  291,  291,  291,  291,  291,
      291,  291,  291,  291,  292,  292,   97,   95,  292,   93,
      292,   89,  292,  293,   88,  293,  293,  293,  293,  293,
      293,  293,  293,  293,  294,  294,  294,  295,  295,  295,
      296,  296,  297,  297,  298,  298,   85,   75,   51,   50,

       48,   46,   45,   43,   40,   38,   37,   34,   29,   18,
       15,   13,   11,    7,  283,  283,  283,  283,  283,  283,
      283,  283,  283,  283,  283,  283,  283,  283,  283,  283,
      283,  283,  283,  283,  283,  283,  283,  283,  283,  283,
      283,  283,  283,  283,  283,  283,  283,  283,  283,  283,
      283,  283,  283,  283,  283,  283,  283,  283,  283,  283,
      283,  283,  283,  283,  283,  283,  283,  283,  283,  283,
      283,  283,  283,  283,  283,  283,  283,  283,  283,  283,
      283,  283
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "cod/cod.l"
#line 18 "cod/cod.l"
static	int lex_offset = 1;
static  int line_count = 1;
static char *create_string_from_yytext();
#define RETURN(val) {yylval.info.lx_srcpos.line = line_count; yylval.info.lx_srcpos.character = lex_offset; lex_offset +=yyleng; return(val);}
static int type_count;
static char**types;
static char**enums;
#ifdef input
/* lex, not flex */
static char *saved_input_str = NULL;
static void 
terminate_string_parse()
{
    if (saved_input_str) {
	free(saved_input_str);
        saved_input_str = NULL;
    }
}

static char *input_str = NULL;
static void
setup_for_string_parse(string, defined_types, enum_constants)
const char *string;
char **defined_types;
char **enum_constants;
{
    int len = strlen(string);

    types = defined_types;
    enums = enum_constants;
    if (saved_input_str != NULL) free(input_str);
    input_str = malloc(len + 2);
    saved_input_str = input_str;
    strcpy(input_str, string);
    input_str[len] = 0;
    input_str[len + 1] = 0;
    lex_offset = 1;
    line_count = 1;
}
#undef input
#define input() (((yytchar=*input_str)==0)?0:(input_str++,yytchar==10?(yylineno++,yytchar):yytchar))
#undef unput
#define unput(c) (input_str--,c==10?yylineno--:yylineno)
#else
/* flex */

#ifdef YY_INPUT
#undef YY_INPUT
extern int my_yy_input();
#define YY_INPUT(buf,x,y) x=my_yy_input(buf,x,y)
#endif

/* end of lex ifdef */
#endif
static
int
is_defined_type(char *id)
{
    int i = 0;
    while(types && types[i]) {
	if (strcmp(id, types[i]) == 0) return 1;
	i++;
    }
    return 0;
}
static
int
is_enumeration_constant(char *id)
{
    int i = 0;
    while(enums && enums[i]) {
	if (strcmp(id, enums[i]) == 0) return 1;
	i++;
    }
    return 0;
}
static void check_strbuf();
static int buffer_len;
static char *string_buffer;
static char *string_buf_ptr;
#line 770 "/build/adios2/src/build/thirdparty/ffs/ffs/lex.yy.c"

#line 772 "/build/adios2/src/build/thirdparty/ffs/ffs/lex.yy.c"

#define INITIAL 0
#define string_cond 1
#define comment 2

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
    static void yyunput ( int c, char *buf_ptr  );
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 101 "cod/cod.l"



#line 995 "/build/adios2/src/build/thirdparty/ffs/ffs/lex.yy.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 284 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 615 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 104 "cod/cod.l"
{RETURN(ARROW);}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 105 "cod/cod.l"
{RETURN(LPAREN);}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 106 "cod/cod.l"
{RETURN(RPAREN);}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 107 "cod/cod.l"
{RETURN(LBRACKET);}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 108 "cod/cod.l"
{RETURN(RBRACKET);}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 109 "cod/cod.l"
{RETURN(DOTDOTDOT);}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 110 "cod/cod.l"
{RETURN(DOT);}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 111 "cod/cod.l"
{RETURN(COMMA);}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 112 "cod/cod.l"
{RETURN(STAR);}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 113 "cod/cod.l"
{RETURN(AT);}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 114 "cod/cod.l"
{RETURN(SLASH);}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 115 "cod/cod.l"
{RETURN(MODULUS);}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 116 "cod/cod.l"
{RETURN(PLUS);}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 117 "cod/cod.l"
{RETURN(MINUS);}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 118 "cod/cod.l"
{RETURN(TILDE);}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 119 "cod/cod.l"
{RETURN(LEQ);}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 120 "cod/cod.l"
{RETURN(LT);}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 121 "cod/cod.l"
{RETURN(GEQ);}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 122 "cod/cod.l"
{RETURN(GT);}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 123 "cod/cod.l"
{RETURN(LEFT_SHIFT);}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 124 "cod/cod.l"
{RETURN(RIGHT_SHIFT);}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 125 "cod/cod.l"
{RETURN(EQ);}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 126 "cod/cod.l"
{RETURN(NEQ);}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 127 "cod/cod.l"
{RETURN(ASSIGN);}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 128 "cod/cod.l"
{RETURN(MUL_ASSIGN);}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 129 "cod/cod.l"
{RETURN(DIV_ASSIGN);}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 130 "cod/cod.l"
{RETURN(MOD_ASSIGN);}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 131 "cod/cod.l"
{RETURN(ADD_ASSIGN);}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 132 "cod/cod.l"
{RETURN(SUB_ASSIGN);}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 133 "cod/cod.l"
{RETURN(LEFT_ASSIGN);}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 134 "cod/cod.l"
{RETURN(RIGHT_ASSIGN);}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 135 "cod/cod.l"
{RETURN(AND_ASSIGN);}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 136 "cod/cod.l"
{RETURN(XOR_ASSIGN);}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 137 "cod/cod.l"
{RETURN(OR_ASSIGN);}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 138 "cod/cod.l"
{RETURN(LOG_OR);}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 139 "cod/cod.l"
{RETURN(LOG_AND);}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 140 "cod/cod.l"
{RETURN(ARITH_OR);}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 141 "cod/cod.l"
{RETURN(ARITH_AND);}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 142 "cod/cod.l"
{RETURN(ARITH_XOR);}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 143 "cod/cod.l"
{RETURN(INC_OP);}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 144 "cod/cod.l"
{RETURN(DEC_OP);}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 145 "cod/cod.l"
{RETURN(SEMI);}
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 146 "cod/cod.l"
{RETURN(IF);}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 147 "cod/cod.l"
{RETURN(ELSE);}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 148 "cod/cod.l"
{RETURN(FOR);}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 149 "cod/cod.l"
{RETURN(WHILE);}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 150 "cod/cod.l"
{RETURN(DO);}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 151 "cod/cod.l"
{RETURN(UNSIGNED);}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 152 "cod/cod.l"
{RETURN(SIGNED);}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 153 "cod/cod.l"
{RETURN(SHORT);}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 154 "cod/cod.l"
{RETURN(INT);}
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 155 "cod/cod.l"
{RETURN(LONG);}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 156 "cod/cod.l"
{RETURN(CHAR);}
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 157 "cod/cod.l"
{RETURN(STRING);}
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 158 "cod/cod.l"
{RETURN(FLOAT);}
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 159 "cod/cod.l"
{RETURN(DOUBLE);}
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 160 "cod/cod.l"
{RETURN(VOID);}
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 161 "cod/cod.l"
{RETURN(STATIC);}
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 162 "cod/cod.l"
{RETURN(EXTERN_TOKEN);}
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 163 "cod/cod.l"
{RETURN(TYPEDEF);}
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 164 "cod/cod.l"
{RETURN(CONTINUE);}
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 165 "cod/cod.l"
{RETURN(BREAK);}
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 166 "cod/cod.l"
{RETURN(GOTO);}
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 167 "cod/cod.l"
{RETURN(CONST);}
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 168 "cod/cod.l"
{RETURN(SIZEOF);}
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 169 "cod/cod.l"
{RETURN(STRUCT);}
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 170 "cod/cod.l"
{RETURN(ENUM);}
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 171 "cod/cod.l"
{RETURN(UNION);}
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 172 "cod/cod.l"
{RETURN(RETURN_TOKEN);}
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 173 "cod/cod.l"
{
			    int count = 0;
			    while(types && types[count]) count++;
			    yylval.info.type_stack_count = count;
			    RETURN(LCURLY);
			}
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 179 "cod/cod.l"
{RETURN(RCURLY);}
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 180 "cod/cod.l"
{RETURN(BANG);}
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 181 "cod/cod.l"
{RETURN(COLON);}
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 182 "cod/cod.l"
{RETURN(QUESTION);}
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 183 "cod/cod.l"
{
				yylval.info.string = create_string_from_yytext();
				if (is_defined_type(yylval.info.string)) {
				    RETURN(type_identifier);
				} else if (is_enumeration_constant(yylval.info.string)) {
				    RETURN(enumeration_constant);
				} else {
				    RETURN(identifier_ref);
				}
			}
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 194 "cod/cod.l"
{
	  buffer_len = 20;
	  string_buffer = malloc(20 + 1);
	  string_buf_ptr = string_buffer; BEGIN(string_cond);
}
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 200 "cod/cod.l"
{ /* saw closing quote - all done */
        BEGIN(INITIAL);
        *string_buf_ptr = '\0';
        /* return string constant token type and
         * value to parser
         */
	yylval.info.string = string_buffer;
	RETURN(string_constant);
}
	YY_BREAK
case 78:
/* rule 78 can match eol */
YY_RULE_SETUP
#line 210 "cod/cod.l"
{
	yyerror("Unterminated string constant");
}
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 214 "cod/cod.l"
{
        /* hex escape sequence */
        int result;

        (void) sscanf( yytext + 2, "%x", &result );

        if ( result > 0xff ) {
	   yyerror("bad hex escape character");
	}

        check_strbuf();
	*string_buf_ptr++ = result;
}
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 228 "cod/cod.l"
{
        /* octal escape sequence */
        int result;

        (void) sscanf( yytext + 1, "%o", &result );

        if ( result > 0xff ) {
	   yyerror("bad octal escape character");
	}

        check_strbuf();
	*string_buf_ptr++ = result;
}
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 242 "cod/cod.l"
{
	 yyerror("bad character escape");
}
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 246 "cod/cod.l"
{check_strbuf();*string_buf_ptr++ = '\n';}
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 247 "cod/cod.l"
{check_strbuf();*string_buf_ptr++ = '\t';}
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 248 "cod/cod.l"
{check_strbuf();*string_buf_ptr++ = '\r';}
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 249 "cod/cod.l"
{check_strbuf();*string_buf_ptr++ = '\b';}
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 250 "cod/cod.l"
{check_strbuf();*string_buf_ptr++ = '\f';}
	YY_BREAK
case 87:
/* rule 87 can match eol */
YY_RULE_SETUP
#line 252 "cod/cod.l"
{check_strbuf();*string_buf_ptr++ = yytext[1];}
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 254 "cod/cod.l"
{
        char *yptr = yytext;

        while ( *yptr ) {
		check_strbuf();
                *string_buf_ptr++ = *yptr++;
        }
}
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 265 "cod/cod.l"
BEGIN(comment);
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 267 "cod/cod.l"
{lex_offset += yyleng;} /* eat anything that's not a '*' */
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 268 "cod/cod.l"
{lex_offset += yyleng;} /* eat up '*'s not followed by '/'s */
	YY_BREAK
case 92:
/* rule 92 can match eol */
YY_RULE_SETUP
#line 269 "cod/cod.l"
{++line_count;lex_offset = 1;}
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 270 "cod/cod.l"
{lex_offset += yyleng;BEGIN(INITIAL);}
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 271 "cod/cod.l"
{ /* consume //-comment */ }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 273 "cod/cod.l"
{
				yylval.info.string = create_string_from_yytext();
				RETURN(character_constant);
			}
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 277 "cod/cod.l"
{
				yylval.info.string = create_string_from_yytext();
				RETURN(integer_constant);
			}
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 281 "cod/cod.l"
{
				yylval.info.string = create_string_from_yytext();
				RETURN(integer_constant);
			}
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 286 "cod/cod.l"
{
				yylval.info.string = create_string_from_yytext();
				RETURN(integer_constant);
			}
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 291 "cod/cod.l"
{
				yylval.info.string = create_string_from_yytext();
				RETURN(floating_constant);
			}
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 295 "cod/cod.l"
{
				yylval.info.string = create_string_from_yytext();
				RETURN(floating_constant);
			}
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 299 "cod/cod.l"
{
				yylval.info.string = create_string_from_yytext();
				RETURN(floating_constant);
			}
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 303 "cod/cod.l"
{
				yylval.info.string = create_string_from_yytext();
				RETURN(floating_constant);
			}
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 308 "cod/cod.l"
{
				yylval.info.string = create_string_from_yytext();
				RETURN(floating_constant);
			}
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 313 "cod/cod.l"
{
				yylval.info.string = create_string_from_yytext();
				RETURN(floating_constant);
			}
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 318 "cod/cod.l"
{lex_offset += yyleng;}
	YY_BREAK
case 106:
/* rule 106 can match eol */
YY_RULE_SETUP
#line 319 "cod/cod.l"
{lex_offset = 1; line_count++;}
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 320 "cod/cod.l"
ECHO;
	YY_BREAK
#line 1682 "/build/adios2/src/build/thirdparty/ffs/ffs/lex.yy.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(string_cond):
case YY_STATE_EOF(comment):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 284 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 284 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 283);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

    static void yyunput (int c, char * yy_bp )
{
	char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = (yy_n_chars) + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 320 "cod/cod.l"

static char *create_string_from_yytext()
{
  char *st = (char *) malloc((yyleng+1)*sizeof(char));
  strcpy (st, yytext);
  return(st);
}

static void check_strbuf()
{
    intptr_t cur_len = string_buf_ptr - string_buffer;
    if ((cur_len + 1) == buffer_len) {
	buffer_len += 20;
	string_buffer = realloc(string_buffer, buffer_len + 1);
	string_buf_ptr = string_buffer + cur_len;
    }
}

#define yy_size_t int
#ifndef yyconst
#define yyconst
#endif 

#define YY_USE_PROTOS

#ifndef YY_PROTO
#ifdef YY_USE_PROTOS
#define YY_PROTO(proto) proto
#else
#define YY_PROTO(proto) ()
#endif
#endif

extern int
yywrap YY_PROTO(( void ))
{
    return 1;
}


/* flex, not lex */
void yy_delete_buffer YY_PROTO((YY_BUFFER_STATE b));


static YY_BUFFER_STATE bb = NULL;

static void
reset_types_table(char **defined_types, char **enumerated_constants)
{
    types = defined_types;
    enums = enumerated_constants;
}

static void
setup_for_string_parse(const char *string, char **defined_types, char **enum_constants)
{
    types = defined_types;
    enums = enum_constants;

    if ((bb = yy_scan_string(string)) == NULL) {
       fprintf(stderr, "yyscan_buffer_failed\n");
     }
    lex_offset = 1;
    line_count = 1;
}

static void 
terminate_string_parse()
{
    if (bb) {
		yy_delete_buffer(bb);
		bb = NULL;
	}
}


